searchData={"content_type":"text/markdown","items":[{"doc":"LenraCommon keeps the contexts that define your domain\nand business logic.","ref":"LenraCommon.html","title":"LenraCommon","type":"module"},{"doc":"LenraCommon.Errors.ErrorGenerator allows to generate two functions following a list of errors.\n  The first function returns the error structure and the second returns the `{:error, _error_struct}` tuple.","ref":"LenraCommon.Errors.ErrorGenerator.html","title":"LenraCommon.Errors.ErrorGenerator","type":"module"},{"doc":"","ref":"LenraCommon.Errors.ErrorGenerator.html#create_struct/3","title":"LenraCommon.Errors.ErrorGenerator.create_struct/3","type":"function"},{"doc":"This code takes care of generating each function corresponding to errors listed in the `@errors` array.\n  It basically loops through the array and generates two functions for each error:\n  - one that returns the error without metadata\n  - one that returns the error with metadata.\n\n  Here is an example. Imagine that the `@errors` array contains the following errors:\n  ```\n    [\n      {:unknown_error, \"Unknown error\"},\n    ]\n  ```\n\n  The following functions will be generated:\n  ```\n    def unknown_error() do\n      %BusinessError{\n        message: \"Unknown error\",\n        reason: :unknown_error\n      }\n    end\n\n    def unknown_error(metadata) do\n      %BusinessError{\n        message: \"Unknown error\",\n        reason: :unknown_error,\n        data: metadata\n      }\n    end\n  ```","ref":"LenraCommon.Errors.ErrorGenerator.html#gen_errors/2","title":"LenraCommon.Errors.ErrorGenerator.gen_errors/2","type":"macro"},{"doc":"LenraCommon.Errors.ErrorStruct defines a basic error struct for Lenra server.","ref":"LenraCommon.Errors.ErrorStruct.html","title":"LenraCommon.Errors.ErrorStruct","type":"module"},{"doc":"JsonHelper gives some function that can help with json maps","ref":"LenraCommon.JsonHelper.html","title":"LenraCommon.JsonHelper","type":"module"},{"doc":"get_in_json allow to get in json map value by path, ex:\n\n  ```\n  my_json_map = %{\n    \"lvl1\" => %{\n      \"lvl2\" => %{\n        \"value\" => \"test\"\n      }\n    }\n  }\n\n  get_in_json(my_json_map, [\"lvl1\", \"lvl2\", \"value\"])\n  ```","ref":"LenraCommon.JsonHelper.html#get_in_json/2","title":"LenraCommon.JsonHelper.get_in_json/2","type":"function"},{"doc":"The entrypoint for defining your web interface, such\nas controllers, views, channels and so on.\n\nThis can be used in your application as:\n\n    use LenraCommonWeb, :controller\n    use LenraCommonWeb, :view\n\nThe definitions below will be executed for every view,\ncontroller, etc, so keep them short and clean, focused\non imports, uses and aliases.\n\nDo NOT define functions inside the quoted expressions\nbelow. Instead, define any helper function in modules\nand import those modules here.","ref":"LenraCommonWeb.html","title":"LenraCommonWeb","type":"module"},{"doc":"When used, dispatch to the appropriate controller/view/etc.","ref":"LenraCommonWeb.html#__using__/1","title":"LenraCommonWeb.__using__/1","type":"macro"},{"doc":"","ref":"LenraCommonWeb.html#controller/0","title":"LenraCommonWeb.controller/0","type":"function"},{"doc":"","ref":"LenraCommonWeb.html#view/0","title":"LenraCommonWeb.view/0","type":"function"},{"doc":"","ref":"LenraCommonWeb.html#view_helpers/0","title":"LenraCommonWeb.view_helpers/0","type":"function"},{"doc":"","ref":"LenraCommonWeb.BaseView.html","title":"LenraCommonWeb.BaseView","type":"module"},{"doc":"The resource name, as an atom, for this view","ref":"LenraCommonWeb.BaseView.html#__resource__/0","title":"LenraCommonWeb.BaseView.__resource__/0","type":"function"},{"doc":"Renders the given template locally.","ref":"LenraCommonWeb.BaseView.html#render/2","title":"LenraCommonWeb.BaseView.render/2","type":"function"},{"doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"LenraCommonWeb.BaseView.html#template_not_found/2","title":"LenraCommonWeb.BaseView.template_not_found/2","type":"function"},{"doc":"ApplicationRunner.ControllerHelpers give some helper functions to assign error/data to the conn and send the response to the view.","ref":"LenraCommonWeb.ControllerHelpers.html","title":"LenraCommonWeb.ControllerHelpers","type":"module"},{"doc":"","ref":"LenraCommonWeb.ControllerHelpers.html#add_error/2","title":"LenraCommonWeb.ControllerHelpers.add_error/2","type":"function"},{"doc":"","ref":"LenraCommonWeb.ControllerHelpers.html#assign_data/2","title":"LenraCommonWeb.ControllerHelpers.assign_data/2","type":"function"},{"doc":"","ref":"LenraCommonWeb.ControllerHelpers.html#assign_error/2","title":"LenraCommonWeb.ControllerHelpers.assign_error/2","type":"function"},{"doc":"","ref":"LenraCommonWeb.ControllerHelpers.html#reply/1","title":"LenraCommonWeb.ControllerHelpers.reply/1","type":"function"},{"doc":"","ref":"LenraCommonWeb.ControllerHelpers.html#reply/2","title":"LenraCommonWeb.ControllerHelpers.reply/2","type":"function"},{"doc":"Conveniences for translating and building error messages.","ref":"LenraCommonWeb.ErrorHelpers.html","title":"LenraCommonWeb.ErrorHelpers","type":"module"},{"doc":"","ref":"LenraCommonWeb.ErrorHelpers.html#translate_error/1","title":"LenraCommonWeb.ErrorHelpers.translate_error/1","type":"function"},{"doc":"","ref":"LenraCommonWeb.ErrorView.html","title":"LenraCommonWeb.ErrorView","type":"module"},{"doc":"","ref":"LenraCommonWeb.FallbackController.html","title":"LenraCommonWeb.FallbackController","type":"module"},{"doc":"LenraCommon.Errors.BusinessError creates all error functions based on the `@errors` list.\n  For each error in the list, this module creates two function,\n  one that creates and returns a BusinessError struct,\n  the second that creates a BusinessError struct and returns it into a tuple.","ref":"LenraCommon.Errors.BusinessError.html","title":"LenraCommon.Errors.BusinessError","type":"exception"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#forbidden/1","title":"LenraCommon.Errors.BusinessError.forbidden/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#forbidden_tuple/1","title":"LenraCommon.Errors.BusinessError.forbidden_tuple/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#integer_array_index/1","title":"LenraCommon.Errors.BusinessError.integer_array_index/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#integer_array_index_tuple/1","title":"LenraCommon.Errors.BusinessError.integer_array_index_tuple/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#nil_json/1","title":"LenraCommon.Errors.BusinessError.nil_json/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#nil_json_tuple/1","title":"LenraCommon.Errors.BusinessError.nil_json_tuple/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#unauthorized/1","title":"LenraCommon.Errors.BusinessError.unauthorized/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#unauthorized_tuple/1","title":"LenraCommon.Errors.BusinessError.unauthorized_tuple/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.BusinessError.html#t:t/0","title":"LenraCommon.Errors.BusinessError.t/0","type":"type"},{"doc":"LenraCommon.Errors.DevError Define the DevError structure.\n  This is the error to raise when we are facing an impossible case (a case that should never happen).\n  This error should be caught into sentry.","ref":"LenraCommon.Errors.DevError.html","title":"LenraCommon.Errors.DevError","type":"exception"},{"doc":"","ref":"LenraCommon.Errors.DevError.html#t:t/0","title":"LenraCommon.Errors.DevError.t/0","type":"type"},{"doc":"LenraCommon.Errors.TechnicalError creates all error functions based on the `@errors` list.\n  For each error in the list, this module creates two function,\n  one that creates and returns a TechnicalError struct,\n  the second that creates a TechnicalError struct and returns it into an tuple.","ref":"LenraCommon.Errors.TechnicalError.html","title":"LenraCommon.Errors.TechnicalError","type":"exception"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#bad_request/1","title":"LenraCommon.Errors.TechnicalError.bad_request/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#bad_request_tuple/1","title":"LenraCommon.Errors.TechnicalError.bad_request_tuple/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#error_404/1","title":"LenraCommon.Errors.TechnicalError.error_404/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#error_404_tuple/1","title":"LenraCommon.Errors.TechnicalError.error_404_tuple/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#error_500/1","title":"LenraCommon.Errors.TechnicalError.error_500/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#error_500_tuple/1","title":"LenraCommon.Errors.TechnicalError.error_500_tuple/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#unknown_error/1","title":"LenraCommon.Errors.TechnicalError.unknown_error/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#unknown_error_tuple/1","title":"LenraCommon.Errors.TechnicalError.unknown_error_tuple/1","type":"function"},{"doc":"","ref":"LenraCommon.Errors.TechnicalError.html#t:t/0","title":"LenraCommon.Errors.TechnicalError.t/0","type":"type"}]}